@@ -37,8 +37,8 @@ def token_request(request_type, values=()):
 
 def retry(message, values):
     yorn = raw_input(
-        message + "\n(yes/[no]): ")
-    if yorn == "yes":
+        message + "\n(y/[n]): ")
+    if yorn == "y":
         execute_request(token_request("getToken", values))
 
 
@@ -46,8 +46,9 @@ def execute_request(reply):
     (status, values) = reply
     if status == "EXISTING":
         yorn = raw_input(
-            "Key already exists. Would you like to change your key? \n(yes/[no]): ")
-        if yorn == "yes":
+            "Key already exists on server. " +
+            "Would you like to change your key and configure the api on this maching? \n(y/[n]): ")
+        if yorn == "y":
             execute_request(token_request("changeToken", values))
     elif status == "NOT_EXISTING":
         retry("Key does not exist. Would you like to try to create one?", values)
